list_of_months_ln
library
Constants
-
listMonthsAr
→ const List<Map<String, Object>>
-
list of months , ar
-
listMonthsDe
→ const List<Map<String, Object>>
-
list of months , de_DE
-
listMonthsElGr
→ const List<Map<String, Object>>
-
list of months , el_GR
-
listMonthsEn
→ const List<Map<String, Object>>
-
This file contains lists of months in various languages and formats.
Each list is a collection of maps, where each map represents a month with an
id and a value.
-
listMonthsEnAbbv
→ const List<Map<String, Object>>
-
list of months , en abbreviations
-
listMonthsEsEs
→ const List<Map<String, Object>>
-
list of months , es_ES
-
listMonthsFrFr
→ const List<Map<String, Object>>
-
list of months , fr_FR
-
listMonthsGu
→ const List<Map<String, Object>>
-
list of months , gu
-
listMonthsHiIn
→ const List<Map<String, Object>>
-
list of months , hi_IN
-
listMonthsIdId
→ const List<Map<String, Object>>
-
list of months , id_ID
-
listMonthsItIt
→ const List<Map<String, Object>>
-
list of months , it_IT
-
listMonthsJa
→ const List<Map<String, Object>>
-
list of months , ja
-
listMonthsKn
→ const List<Map<String, Object>>
-
list of months , kn
-
listMonthsKoKr
→ const List<Map<String, Object>>
-
list of months , ko_KR
-
listMonthsMl
→ const List<Map<String, Object>>
-
list of months , ml
-
listMonthsMr
→ const List<Map<String, Object>>
-
list of months , mr
-
listMonthsNlNl
→ const List<Map<String, Object>>
-
list of months , nl_NL
-
listMonthsNum
→ const List<Map<String, Object>>
-
list of months , numeric
-
listMonthsPlPl
→ const List<Map<String, Object>>
-
list of months , pl_PL
-
listMonthsPtBr
→ const List<Map<String, Object>>
-
list of months , pt_BR
-
listMonthsRuRu
→ const List<Map<String, Object>>
-
list of months , ru_RU
-
listMonthsSvSe
→ const List<Map<String, Object>>
-
list of months , sv_SE
-
listMonthsTa
→ const List<Map<String, Object>>
-
list of months , ta
-
listMonthsTe
→ const List<Map<String, Object>>
-
list of months , te
-
listMonthsTh
→ const List<Map<String, Object>>
-
list of months , th
-
listMonthsTr
→ const List<Map<String, Object>>
-
list of months , tr
-
listMonthsVi
→ const List<Map<String, Object>>
-
list of months , vi
-
listMonthsZhCn
→ const List<Map<String, Object>>
-
list of months , zh_CN
-
monthOptionsByLocale
→ const Map<String, List<Map<String, Object>>>
-
A locale-to-month-options lookup used by the date picker widget.
-
supportedDatePickerLocales
→ const Set<String>
-
The locales supported by the date picker package.